/* ChanServ help texts. */

static const char *cs_help[] = {
"\2ChanServ\2 allows you to register and control various",
"aspects of channels.  ChanServ can often prevent",
"malicious users from \"taking over\" channels by limiting",
"who is allowed channel operator priviliges.  ChanServ's",
"commands are listed below; to use them, type",
"\2/msg ChanServ <command>\2.  For more information on a",
"specific command, type \2/msg ChanServ help \37command\37\2.",
" ",
"    REGISTER   Register a channel",
"    IDENTIFY   Identify yourself with your password",
"    SET        Set channel options and information",
"    ACCESS     Modify the list of privileged users",
"    AKICK      Maintain the AutoKick list",
"    DROP       Cancel the registration of a channel",
" ",
"Other commands: INFO, LIST, INVITE",
" ",
"Note that any channel which is not used for two weeks",
"(i.e. which no user on the channel's access list enters",
"for that period of time) will be automatically dropped.",
NULL
};

static const char *register_help[] = {
"Syntax: \2REGISTER \37channel\37 \37password\37 \37description\37\2",
" ",
"Registers a channel in the ChanServ database.  In order",
"to use this command, you must first be a channel operator",
"on the channel you're trying to register.  The password",
"is used with the \2IDENTIFY\2 command to allow you to",
"make changes to the channel settings at a later time.",
"The last parameter, which \2must\2 be included, is a",
"general description of the channel's purpose.",
" ",
"When you register a channel, you are recorded as the",
"\"founder\" of the channel.  The channel founder is allowed",
"to change all of the channel settings for the channel;",
"ChanServ will also automatically give the founder",
"channel-operator privileges when s/he enters the channel.",
"See the \2ACCESS\2 command (\2/msg ChanServ HELP ACCESS\2) for",
"information on giving a subset of these privileges to",
"other channel users.",
" ",
"NOTICE: In order to register a channel, you must first",
"registered your nickname.  If you haven't,",
"\2/msg NickServ HELP\2 for information on how to do so.",
NULL
};

static const char *identify_help[] = {
"Syntax: \2IDENTIFY \37channel\37 \37password\37",
" ",
"Authenticates you to ChanServ as the founder of the given",
"channel.  Many commands require you to use this command",
"before using them.  The password should be the same one",
"you sent with the \2REGISTER\2 command.",
NULL
};

static const char *drop_help[] = {
"Syntax: \2DROP \37channel\37\2",
" ",
"Unregisters the named channel.  Can only be used by",
"\2channel founder\2, who must use the \2IDENTIFY\2 command first.",
NULL
};

static const char *oper_drop_help[] = {
"Syntax: \2DROP \37channel\37\2",
" ",
"Unregisters the named channel.",
NULL
};

static const char *set_help[] = {
"Syntax: \2SET \37channel\37 \37option\37 \37parameters\37\2",
" ",
"Allows the channel founder to set various channel options",
"and other information.  The founder must use the \2IDENTIFY\2",
"command before using \2SET\2.",
" ",
"Available options:",
" ",
"    FOUNDER     Set the founder of a channel",
"    PASSWORD    Set the founder password",
"    DESC        Set the channel description",
"    TOPIC       Change the topic on a channel",
"    MLOCK       Lock channel modes on or off",
"    KEEPTOPIC   Retain topic when channel is not in use",
"    LOCKTOPIC   Topic can only be changed with SET TOPIC",
"    PRIVATE     Hide channel from ChanServ lists",
"    SECUREOPS   Stricter control of chanop status",
NULL
};

static const char *set_founder_help[] = {
"Syntax: \2SET \37channel\37 FOUNDER \37nick\37\2",
" ",
"Changes the founder of a channel.  The new nickname must",
"be a registered one.",
NULL
};

static const char *set_pass_help[] = {
"Syntax: \2SET \37channel\37 PASSWORD \37password\37\2",
" ",
"Sets the password used to identify as the founder of the",
"channel.",
NULL
};

static const char *set_desc_help[] = {
"Syntax: \2SET \37channel\37 DESC \37description\37\2",
" ",
"Sets the description for the channel, which shows up with",
"the \2LIST\2 and \2INFO\2 commands.",
NULL
};

static const char *set_topic_help[] = {
"Syntax: \2SET \37channel\37 TOPIC \37topic\37\2",
" ",
"Causes ChanServ to set the channel topic to the one",
"specified.  This command is most useful in conjunction",
"with SET LOCKTOPIC.",
NULL
};

static const char *set_mlock_help[] = {
"Syntax: \2SET \37channel\37 MLOCK \37modes\37\2",
" ",
"Sets the mode-lock parameter for the channel.  ChanServ",
"allows you to define certain channel modes to be always",
"on (or off).  The modes that can be locked are \2i\2, \2k\2, \2l\2,",
"\2m\2, \2n\2, \2p\2, \2s\2, and \2t\2; each of these modes can be locked on,",
"locked off, or not locked.  The <modes> parameter is",
"constructed exactly the same way as a \2/MODE\2 command; that",
"is, modes followed by a + are locked on, and modes",
"followed by a - are locked off.",
" ",
"Examples:",
" ",
"    SET #channel MLOCK +nt-iklps",
"       Forces modes n and t on, and modes i, k, l, p, and",
"       s off.  Mode m is left free to be either on or off.",
" ",
"    SET #channel MLOCK +knst-ilmp my-key",
"       Forces modes k, n, s, and t on, and modse i, l, m,",
"       and p off.  Also forces the channel key to be",
"       \"my-key\".",
" ",
"    SET #channel MLOCK +",
"       Removes the mode lock; all channel modes are free",
"       to be either on or off.",
NULL
};

static const char *set_keeptopic_help[] = {
"Syntax: \2SET \37channel\37 KEEPTOPIC {ON|OFF}\2",
" ",
"Enables or disables the \2topic retention\2 option for a",
"channel.  When \2topic retention\2 is set, the topic for the",
"channel will be remembered by ChanServ even after the",
"last user leaves the channel, and will be restored the",
"next time the channel is created.",
NULL
};

static const char *set_topiclock_help[] = {
"Syntax: \2SET \37channel\37 TOPICLOCK {ON|OFF}\2",
" ",
"Enables or disables the \2topic lock\2 option for a channel.",
"When \2topic lock\2 is set, ChanServ will not allow the",
"channel topic to be changed except via the SET TOPIC",
"command.",
NULL
};

static const char *set_private_help[] = {
"Syntax: \2SET \37channel\37 PRIVATE {ON|OFF}\2",
" ",
"Enables or disables the \2private\2 option for a channel.",
"When \2private\2 is set, a \2/msg ChanServ LIST\2 will not",
"include the channel in any lists.",
NULL
};

static const char *set_secureops_help[] = {
"Syntax: \2SET \37channel\37 SECUREOPS {ON|OFF}\2",
" ",
"Enables or disables the \2secure ops\2 option for a channel.",
"When \2secure-ops\2 is set, users who are not on the userlist",
"will not be allowed chanop status.",
NULL
};

static const char *set_restricted_help[] = {
"Syntax: \2SET \37channel\37 RESTRICTED {ON|OFF}\2",
" ",
"Enables or disables the \2restricted access\2 option for a",
"channel.  When \2restricted access\2 is set, users who would",
"normally be disallowed from having channel operator",
"privileges (users with negative access levels and, if",
"\2secure ops\2 is set, users not on the access list) will",
"instead be kicked and banned from the channel.",
NULL
};

static const char *access_help[] = {
"Syntax: \2ACCESS \37channel\37 ADD \37mask\37 \37level\37",
"        \2ACCESS \37channel\37 DEL {\37mask\37 | \37entry-num\37}",
"        \2ACCESS \37channel\37 LIST [\37mask\37]",
" ",
"Maintains the \2access list\2 for a channel.  The access",
"list specifies which users are allowed chanop status or",
"access to ChanServ commands on the channel.  Different",
"user levels allow for access to different subsets of",
"privileges; \2/msg ChanServ HELP ACCESS LEVELS\2 for more",
"specific information.  By default, any nick not on the",
"access list has a user level of 0.",
" ",
"The \2ACCESS ADD\2 command adds the given nickname or",
"usermask to the access list with the given user level; if",
"the nick or mask is already present on the list, its",
"access level is changed to the level specified in the",
"command.",
" ",
"The \2ACCESS DEL\2 command removes the given nick or mask",
"from the access list.",
" ",
"The \2ACCESS LIST\2 command displays the access list; if",
"a mask is given, only those entries matching the mask are",
"displayed.",
NULL
};

static const char *levels_help[] = {
"\2User access levels\2",
" ",
"There are currently five distinct access levels",
"available:",
" ",
"\2Founder\2   Full access to ChanServ functions; automatic",
"                  opping upon entering channel.  Note",
"                  that only one person may have founder",
"                  status (it cannot be given using the",
"                  \2ACCESS\2 command).",
"\2     10\2   Access to AKICK command; automatic opping.",
"\2      5\2   Automatic opping.",
"\2      0\2   No special privileges; can be opped by other",
"                  ops (unless \2secure-ops\2 is set).",
"\2     <0\2   May not be opped.",
" ",
"In addition, any user with access level greater than zero",
"can add other users to the access list, as long as the new",
"entries are for levels less than the user's own.  So, for",
"example, a level 10 user can add level 5 users, and either",
"a level 10 or a level 5 user can add negative-level users.",
"Founders can add users at any level they want.",
NULL
};

static const char *akick_help[] = {
"Syntax: \2AKICK \37channel\37 ADD \37mask\37 [\37reason\37]\2",
"        \2AKICK \37channel\37 DEL \37mask\37\2",
"        \2AKICK \37channel\37 LIST [\37mask\37]\2",
" ",
"Maintains the \2AutoKick list\2 for a channel.  If a user",
"on the AutoKick list attempts to join the channel,",
"ChanServ will ban that user from the channel, then kick",
"the user.",
" ",
"The \2AKICK ADD\2 command adds the given nick or usermask",
"to the AutoKick list.  If a \37reason\37 is given with",
"the command, that reason will be used when the user is",
"kicked; if not, the default reason is \"You have been",
"banned from the channel\".",
" ",
"The \2AKICK DEL\2 command removes the given nick or mask",
"from the AutoKick list.  It does not, however, remove any",
"bans placed by an AutoKick; those must be removed",
"manually.",
" ",
"The \2AKICK LIST\2 command displays the AutoKick list, or",
"optionally only those AutoKick entries which match the",
"given mask.",
NULL
};

static const char *info_help[] = {
"Syntax: \2INFO \37channel\37\2",
" ",
"Lists information about the named registered channel,",
"including its founder, time of registration, last time",
"used, description, and mode lock, if any.",
NULL
};

static const char *list_help[] = {
"Syntax: \2LIST \37mask\37\2",
" ",
"Lists all registered channels matching the given mask.",
"(Channels with the PRIVATE option set are not listed, of",
"course.)",
NULL
};

static const char *invite_help[] = {
"Syntax: \2INVITE \37channel\37\2",
" ",
"Tells ChanServ to invite you into the given channel.",
"Only works if your access level on that channel is",
"greater than zero.",
NULL
};

static const char *unban_help[] = {
"Syntax: \2UNBAN \37channel\37\2",
" ",
"Tells ChanServ to remove all bans preventing you from",
"entering the given channel.  Only works if your access",
"level on that channel is greater than zero.",
NULL
};

static const char *getpass_help[] = {
"Syntax: \2GETPASS \37channel\37\2",
" ",
"Returns the password for the given channel.  \2Note that\2",
"\2whenever this command is used, a message including the\2",
"\2person who issued the command and the channel it was used\2",
"\2on will be logged and sent out as a WALLOPS.\2",
NULL
};
